@@ -27,6 +27,8 @@ include/rpl_ioctl.h - IOCTL numbers for RPLDEV
 #if defined(__linux__) && defined(__KERNEL__)
 #    include <linux/ioctl.h>
 #    include <linux/types.h>
+#elif defined(__FreeBSD__) && defined(_KERNEL)
+#    include <sys/ioccom.h>
 #else // userspace
 #    include <sys/types.h>
 #    include <sys/ioctl.h>
