@@ -28,6 +28,8 @@ include/rpl_packet.h - Packet definitions for RPLD and RPLDEV
 
 #if defined(__linux__) && defined(__KERNEL__)
 #    include <linux/types.h>
+#elif defined(__FreeBSD__) && defined(_KERNEL)
+#    include <sys/types.h>
 #else // userspace
 #    include <stdint.h>
 #endif
