@@ -141,8 +141,8 @@ static void *client_thread(void *arg) {
 
             // Other
             default:
-                notify(LOG_WARNING, "[infod] Unknown request %d, closing"
-                 " connection to not run into conversion problems.\n", req);
+                notify(LOG_WARNING, _("[infod] Unknown request %d, closing"
+                 " connection to not run into conversion problems.\n"), req);
                 goto clthr__exit;
         }
 
