@@ -59,6 +59,7 @@ static unsigned long k_version_data = 0;
 static pthread_mutex_t k_version_lock = PTHREAD_MUTEX_INITIALIZER;
 
 //-----------------------------------------------------------------------------
+#if defined(__linux__)
 static const char *m_idx = "pqrstuvwxyzabcdef", *s_idx = "0123456789abcdef";
 
 char *G_devname_nm(uint32_t dev, char *buf, size_t count) {
@@ -172,6 +173,59 @@ char *G_devname_fs(uint32_t dev, char *buf, size_t count) {
     return buf;
 }
 
+#elif defined(__FreeBSD__)
+/* It is completely wicked. A lot of devices are assigned dynamic major numbers
+(good idea but does not work in harmony with rpld ;-) Also disappointing is the
+major number difference to Linux, as well as the [ms]_idx. */
+
+static const char *m_idx = "pqrsPQRS",
+ *s_idx = "0123456789abcdefghijklmnopqrstuv";
+
+char *G_devname_nm(uint32_t dev, char *buf, size_t count) {
+    register unsigned long major = K26_MAJOR(dev), minor = K26_MINOR(dev);
+    *buf = '\0';
+
+    switch(major) {
+        case 0:
+            snprintf(buf, count, "console");
+            break;
+        case 5:
+            snprintf(buf, count, "tty%c%c",
+             m_idx[minor / 16], s_idx[minor % 16]);
+            break;
+        case 6:
+            snprintf(buf, count, "pty%c%c",
+             m_idx[minor / 16], s_idx[minor % 16]);
+            break;
+    }
+
+    if(*buf == '\0') { snprintf(buf, count, "[%lu:%lu]", major, minor); }
+    return buf;
+}
+
+char *G_devname_fs(uint32_t dev, char *buf, size_t count) {
+    register unsigned long major = K26_MAJOR(dev), minor = K26_MINOR(dev);
+    *buf = '\0';
+
+    switch(major) {
+        case 0:
+            snprintf(buf, count, "/dev/console");
+            break;
+        case 5:
+            snprintf(buf, count, "/dev/tty%c%c",
+             m_idx[minor / 16], s_idx[minor % 16]);
+            break;
+        case 6:
+            snprintf(buf, count, "/dev/pty%c%c",
+             m_idx[minor / 16], s_idx[minor % 16]);
+            break;
+    }
+
+    if(*buf == '\0') { return NULL; }
+    return buf;
+}
+#endif
+
 struct tty *get_tty(uint32_t dev, int create) {
     struct HXbtree_node *ts;
     struct tty *ret = NULL, *tty;
@@ -188,7 +242,7 @@ struct tty *get_tty(uint32_t dev, int create) {
 
     if((ts = HXbtree_add(Ttys, (void *)dev, tty)) == NULL) {
         free(tty);
-        notify(LOG_ERR, "%s: Memory allocation failure\n", __FUNCTION__);
+        notify(LOG_ERR, _("%s: Memory allocation failure\n"), __FUNCTION__);
         return NULL;
     }
 
