@@ -95,19 +95,19 @@ int main(int argc, const char **argv) {
 
     fprintf(stderr, "> ttyreplay " TTYRPLD_VERSION "\n");
     fprintf(stderr,
-      "This program comes with ABSOLUTELY NO WARRANTY; it is free "
+      _("This program comes with ABSOLUTELY NO WARRANTY; it is free "
       "software\n" "and you are welcome to redistribute it under certain "
       "conditions; for\n" "details see the COPYING file which should have "
-      "come with this program.\n"
+      "come with this program.\n")
     );
 
     if(argc == 0) {
         if(!isatty(STDIN_FILENO)) {
-            fprintf(stderr, "No arguments given but STDIN seems to be a "
-              "pipe/file -- replaying from STDIN\n");
+            fprintf(stderr, _("No arguments given but STDIN seems to be a "
+              "pipe/file -- replaying from STDIN\n"));
             argv = auto_stdin;
         } else {
-            fprintf(stderr, "No filename(s) given.\n");
+            fprintf(stderr, _("No filename(s) given.\n"));
             exit(EXIT_FAILURE);
         }
     }
@@ -120,7 +120,7 @@ int main(int argc, const char **argv) {
         int fd, rv;
         if(strcmp(argv[i], "-") == 0) { argv[i] = "/dev/stdin"; }
         if((fd = open(argv[i], O_RDONLY)) < 0) {
-            fprintf(stderr, "Could not open %s: %s\n",
+            fprintf(stderr, _("Could not open %s: %s\n"),
               argv[i], strerror(errno));
             ++i;
             continue;
@@ -169,8 +169,8 @@ static int replay_file(int fd, const char *name) {
     while((eax = read_waitfm(fd, &packet, sizeof(struct disk_packet))) ==
      sizeof(struct disk_packet)) {
         if(packet.magic != MAGIC_SIG) {
-            fprintf(stderr, "\n" "<Packet inconsistency! "
-             "Trying to find next valid packet.>\n");
+            fprintf(stderr, _("\n" "<Packet inconsistency! "
+             "Trying to find next valid packet.>\n"));
             tick = 0;
             /* If read() in find_next_packet() generates an error, it will be
             catched when the condition is re-evaulated upon continue. */
@@ -187,13 +187,13 @@ static int replay_file(int fd, const char *name) {
                 e_proc(fd, &packet, &ps, &tick, &stamp, &skew);
                 break;
             case EVT_IDENT:
-                fprintf(stderr, "\n\e[1;37m%s ", "Created using"); // ]
+                fprintf(stderr, "\n\e[1;37m%s ", _("Created using")); // ]
                 read_through(fd, STDERR_FILENO, packet.size);
                 fprintf(stderr, "\e[0m\n"); // ]
                 break;
             case EVT_DEINIT:
                 fprintf(stderr, "\n\e[1;37;41m%s\e[0m\n", // ]]
-                 "<tty device has been closed>");
+                 _("<tty device has been closed>"));
                 // fallthrough kinda
                 read_nullfm(fd, packet.size);
                 break;
@@ -217,11 +217,11 @@ static int replay_file(int fd, const char *name) {
 
     if(eax < 0) {
         fprintf(stderr, "\n\e[1;37;41m%s\e[0m\nread(): %s\n", // ]]
-         "<Error while reading from stream>", strerror(errno));
+         _("<Error while reading from stream>"), strerror(errno));
     }
 
     printf("\n\e[1;37;41m"); // ]
-    printf("<Log replaying of %s finished>", name);
+    printf(_("<Log replaying of %s finished>"), name);
     printf("\e[0m\n"); // ]
     return ps.brk;
 }
@@ -297,7 +297,7 @@ static unsigned long calc_ovcorr(unsigned long ad, int rd) {
     unsigned long av = 0;
     int count = rd;
 
-    fprintf(stderr, "Calculating average overhead...");
+    fprintf(stderr, _("Calculating average overhead..."));
 
     while(count--) {
         gettimeofday(&start, NULL);
@@ -392,7 +392,7 @@ static int find_next_packet(int fd) {
         if(++ok >= 2) { break; }
     }
 
-    fprintf(stderr, "\n" "<Found packet boundary>\n");
+    fprintf(stderr, _("\n" "<Found packet boundary>\n"));
 
     // Finally adjust the read pointer to a packet boundary
     if((s = packet->size) < 16) {
@@ -419,24 +419,24 @@ static int get_options(int *argc, const char ***argv) {
     char *tmp = NULL;
     struct poptOption options_table[] = {
         {"no-pctrl", 0, POPT_ARG_NONE, &Opt.no_pctrl, 0,
-         "Do not enable playing controls", NULL},
+         _("Do not enable playing controls"), NULL},
         {NULL, 'F', POPT_ARG_NONE, NULL, 'F',
-         "Live feed follow mode (like `tail -f`)", NULL},
+         _("Live feed follow mode (like `tail -f`)"), NULL},
         {NULL, 'J', POPT_ARG_STRING, &tmp, 'J',
-         "Seek to time position (HH:MM:SS or total SEC, "
-         "see docs)", "tspec"},
+         _("Seek to time position (HH:MM:SS or total SEC, "
+         "see docs)"), "tspec"},
         {NULL, 'S', POPT_ARG_DOUBLE, &Opt.factor, '\0',
-         "Speed factor (default: 1.0)", NULL},
+         _("Speed factor (default: 1.0)"), NULL},
         {NULL, 'T', POPT_ARG_NONE, &Opt.nodelay, 'T',
-         "No delays (useful for text file grepping)", NULL},
+         _("No delays (useful for text file grepping)"), NULL},
         {NULL, 'f', POPT_ARG_NONE, NULL, 'f',
-         "Catch-up follow mode (play file, switch to live feed on EOF)", NULL},
+         _("Catch-up follow mode (play file, switch to live feed on EOF)"), NULL},
         {NULL, 'j', POPT_ARG_LONG, &Opt.skval, 'j',
-         "Skip the given number of EVT_WRITE packets", NULL},
+         _("Skip the given number of EVT_WRITE packets"), NULL},
         {NULL, 'm', POPT_ARG_LONG, &Opt.maxdelay, 'm',
-         "Maximum delay to wait between packets", "msec"},
+         _("Maximum delay to wait between packets"), "msec"},
         {NULL, 't', POPT_ARG_NONE, NULL, 't',
-         "Show the timestamp at the top of the screen", NULL},
+         _("Show the timestamp at the top of the screen"), NULL},
         POPT_AUTOHELP
         POPT_TABLEEND
     };
@@ -550,7 +550,7 @@ static ssize_t read_waitfm(int fd, void *buf, size_t count) {
     the file size increases inbetween. */
     if(Opt.follow == FM_CATCHUP && (pos = lseek(fd, 0, SEEK_CUR)) != 0 &&
      fstat(fd, &sb) == 0 && pos == sb.st_size) {
-        fprintf(stderr, "\n" "<Switching to live feed follow mode>\n");
+        fprintf(stderr, _("\n" "<Switching to live feed follow mode>\n"));
         Opt.follow = FM_LIVE;
     }
 
@@ -566,8 +566,8 @@ static int seek_to_end(int fd) {
         fcntl(fd, F_SETFL, fcntl(fd, F_GETFL) | O_NONBLOCK);
 
         fprintf(stderr,
-          "Reading from something that does not support seeking (a pipe?),\n"
-          "skipping to a position where reading would block\n"
+          _("Reading from something that does not support seeking (a pipe?),\n"
+          "skipping to a position where reading would block\n")
         );
 
         while(read(fd, buf, BUFSIZE) > 0);
