@@ -61,15 +61,15 @@ static int Sockfd = -1;
 //-----------------------------------------------------------------------------
 int rplctl_main(int argc, const char **argv) {
     if((Sockfd = unix_client(GOpt.infod_port)) < 0) {
-        fprintf(stderr, "Connection to %s failed: %s\n",
+        fprintf(stderr, _("Connection to %s failed: %s\n"),
          GOpt.infod_port, strerror(errno));
         return EXIT_FAILURE;
     }
 
     if(get_options(&argc, &argv) == 0) {
         if(!Opt.parseable) {
-            printf("A %-3s %13s %9s %s\n", "TTY", "BYTES IN",
-             "OUT", "FILENAME");
+            printf("A %-3s %13s %9s %s\n", _("TTY"), _("BYTES IN"),
+             _("OUT"), _("FILENAME"));
         }
         send_int(Sockfd, IFP_GETINFO_A, 0);
     }
@@ -90,8 +90,8 @@ static uint32_t getdev(const char *s) {
         in form of "=MAJOR,MINOR". */
         char *sdup = HX_strdup(s), *p = sdup, *minor_str;
         if((minor_str = strpbrk(p + 1, ",.:")) == NULL || p + 1 == minor_str) {
-            fprintf(stderr, "getdev(): Incorrect device number specification"
-             " \"%s\", should be \"=%%d:%%d\"\n", s);
+            fprintf(stderr, _("getdev(): Incorrect device number specification"
+             " \"%s\", should be \"=%%d:%%d\"\n"), s);
             free(sdup);
             return 0;
         }
@@ -114,14 +114,14 @@ static uint32_t getdev(const char *s) {
                 break;
             }
             if(errno != ENOENT) {
-                fprintf(stderr, "Cannot stat %s: %s\n",
+                fprintf(stderr, _("Cannot stat %s: %s\n"),
                  buf, strerror(errno));
                 return 0;
             }
             ++dirp;
         }
         if(!found) {
-            fprintf(stderr, "Cannot find %s\n", s);
+            fprintf(stderr, _("Cannot find %s\n"), s);
             return 0;
         }
 
@@ -207,21 +207,21 @@ static int get_options(int *argc, const char ***argv) {
     char *tmp;
     struct poptOption options_table[] = {
         {NULL, 'A', POPT_ARG_STRING, &tmp, 'A',
-         "Capture data from tty", "tty"},
+         _("Capture data from tty"), "tty"},
         {NULL, 'D', POPT_ARG_STRING, &tmp, 'D',
-         "Ignore data from tty", "tty"},
+         _("Ignore data from tty"), "tty"},
         {NULL, 'L', POPT_ARG_STRING | POPT_ARGFLAG_OPTIONAL, &tmp, 'L',
-         "Explicitly request info about all [or given] ttys", "tty"},
+         _("Explicitly request info about all [or given] ttys"), "tty"},
         {NULL, 'S', POPT_ARG_STRING, &tmp, 'S',
-         "Ignore data from tty until next tty session", "tty"},
+         _("Ignore data from tty until next tty session"), "tty"},
         {NULL, 'X', POPT_ARG_STRING, &tmp, 'X',
-         "Close the tty's logfile", "tty"},
+         _("Close the tty's logfile"), "tty"},
         {NULL, 'Z', POPT_ARG_STRING | POPT_ARGFLAG_OPTIONAL, &tmp, 'Z',
-         "Zero all packet and byte counters", "tty"},
+         _("Zero all packet and byte counters"), "tty"},
         {NULL, 'f', POPT_ARG_STRING, &GOpt.infod_port, 0,
-         "Path to the INFOD socket", "file"},
+         _("Path to the INFOD socket"), "file"},
         {NULL, 't', POPT_ARG_NONE, &Opt.parseable, 0,
-         "Generate easy-parseable output", NULL},
+         _("Generate easy-parseable output"), NULL},
         POPT_AUTOHELP
         POPT_TABLEEND
     };
