@@ -69,6 +69,7 @@ static void sighandler_int(int);
 static void sighandler_alrm(int);
 static void sighandler_pipe(int);
 
+static void chkconf(void);
 static int get_options(int *, const char ***);
 static int read_config(const char *);
 static int read_config_bp(const char *, const char *);
@@ -90,10 +91,10 @@ static struct {
 } Opt = {
     ._running    = 1,
     .bsize       = 16384,
-    .ovdev       = NULL,          // -D
+    .ovdev       = NULL, // -D
     .fbdev       = "/dev/rpl:/dev/misc/rpl",
-    .dolog       = 1,             // !-Q
-    .infod_start = 0,             // -I
+    .dolog       = 1,    // !-Q
+    .infod_start = 0,    // -I
 };
 
 //-----------------------------------------------------------------------------
@@ -101,17 +102,21 @@ int main(int argc, const char **argv) {
     pthread_t infod_id;
     int fd;
 
+    setlocale(LC_ALL, "");
+    bindtextdomain("ttyrpld", "/home/jengelha/f/ttyrpld/locale");
+    textdomain("ttyrpld");
+
     umask(umask(S_IWUSR | S_IWOTH) | S_IRUGO | S_IRWXG | S_IRWXO); // 0022,0477
 
     /* Yep, the config file is what is needed by all three
     (rpld, infod, rplctl). */
     if(!read_config("/etc/rpld.conf") && errno != ENOENT) {
-        fprintf(stderr, "/etc/rpld.conf exists but could not be read: %s\n",
+        fprintf(stderr, _("/etc/rpld.conf exists but could not be read: %s\n"),
          strerror(errno));
     }
     if(!read_config_bp(*argv, "rpld.conf") && errno != ENOENT) {
-        fprintf(stderr, "$BINPATH/rpld.conf exists but could not be"
-         " read: %s\n", strerror(errno));
+        fprintf(stderr, _("$BINPATH/rpld.conf exists but could not be"
+         " read: %s\n"), strerror(errno));
     }
 
     if(strcmp(basename(*argv), "rplctl") == 0) {
@@ -123,10 +128,10 @@ int main(int argc, const char **argv) {
 
     if(GOpt.verbose) {
         printf("# rpld " TTYRPLD_VERSION "\n");
-        printf("This program comes with ABSOLUTELY NO WARRANTY; it is free "
+        printf(_("This program comes with ABSOLUTELY NO WARRANTY; it is free "
           "software\n" "and you are welcome to redistribute it under certain "
           "conditions; for\n" "details see the COPYING file which should have "
-          "come with this program.\n"
+          "come with this program.\n")
         );
     }
 
@@ -137,7 +142,7 @@ int main(int argc, const char **argv) {
     }
 
     if((fd = init_device((Opt.ovdev != NULL) ? Opt.ovdev : Opt.fbdev)) < 0) {
-        fprintf(stderr, "No device could be opened, aborting.\n");
+        fprintf(stderr, _("No device could be opened, aborting.\n"));
         return EXIT_FAILURE;
     }
 
@@ -150,7 +155,7 @@ int main(int argc, const char **argv) {
     if(GOpt.syslog)     { openlog("rpld", LOG_PID, LOG_DAEMON); }
 
     // Not seteuid(), because it shall not be posibble to regain privs.
-    if(GOpt.user_id >= 0) { setuid(GOpt.user_id); }
+    if(GOpt.user_id > 0) { setuid(GOpt.user_id); }
     if(Opt.infod_start) { pthread_create(&infod_id, NULL, infod_main, NULL); }
     mainloop(fd);
 
@@ -171,7 +176,7 @@ static void mainloop(int fd) {
         struct tty *tty;
 
         if(read(fd, &packet, sizeof(struct rpld_packet)) <
-         sizeof(struct rpld_packet)) {
+         (ssize_t)sizeof(struct rpld_packet)) {
             Opt._running = 0;
             break;
         }
@@ -181,7 +186,7 @@ static void mainloop(int fd) {
 
         if(packet.magic != MAGIC_SIG) {
             ++Stats.badpack;
-            notify(LOG_WARNING, "Bogus packet (magic is 0x%02X)!\n",
+            notify(LOG_WARNING, _("Bogus packet (magic is 0x%02X)!\n"),
              packet.magic);
             continue;
         }
@@ -251,7 +256,7 @@ static int packet_preprox(struct mem_packet *packet) {
             Stats.out += packet->size;
             break;
         default:
-            notify(LOG_WARNING, "Unknown packet type 0x%02X\n", packet->event);
+            notify(LOG_WARNING, _("Unknown packet type 0x%02X\n"), packet->event);
             return 0;
     }
 
@@ -279,8 +284,8 @@ static int packet_process(struct mem_packet *packet, struct tty *tty, int fd) {
             log_close(tty);
             break;
         default:
-            notify(LOG_ERR, "Should never get here! (%s:%d) Forgot to code"
-             " something? (event=%d)\n", __FILE__, __LINE__, packet->event);
+            notify(LOG_ERR, _("Should never get here! (%s:%d) Forgot to code"
+             " something? (event=%d)\n"), __FILE__, __LINE__, packet->event);
             break;
     }
 
@@ -321,7 +326,7 @@ static int log_open(struct tty *tty) {
       struct stat sb;
       G_devname_fs(tty->dev, devnode, sizeof(devnode));
       if(stat(devnode, &sb) != 0) {
-          strcpy(user, "NONE");
+          strcpy(user, _("NONE"));
       } else {
           tty->uid = sb.st_uid;
           if(getnamefromuid(sb.st_uid, user, sizeof(user)) == NULL) {
@@ -347,11 +352,11 @@ static int log_open(struct tty *tty) {
     if(!Opt.dolog) {
         snprintf(buf, MAXFNLEN, "/dev/null");
     } else if(check_parent_directory(buf) <= 0) {
-        notify(LOG_ERR, "Directory permission denied: It won't be possible to"
-         " write to the file %s, expect warnings.\n", buf);
+        notify(LOG_ERR, _("Directory permission denied: It won't be possible to"
+         " write to the file %s, expect warnings.\n"), buf);
     }
     if((tty->fd = open(buf, O_WRONLY | O_CREAT | O_APPEND, S_IWUSR)) < 0) {
-        notify(LOG_ERR, "Could not open %s: %s\n", buf, strerror(errno));
+        notify(LOG_ERR, _("Could not open %s: %s\n"), buf, strerror(errno));
     }
 
     // Ident header (optional)
@@ -401,13 +406,13 @@ static int init_device(const char *in_devs) {
         if((fd = open(new_dev, O_RDONLY)) == -1) {
             int se = errno;
             new_dev = NULL;
-            perror("dynamic_find(): Could not open RPL device");
+            perror(_("dynamic_find(): Could not open RPL device"));
             if(se == EBUSY) {
-                fprintf(stderr, "\t" "The RPL device can only be opened once,"
-                 "\n\t" "there is probably an instance of rpld running!\n");
+                fprintf(stderr, _("\t" "The RPL device can only be opened once,"
+                 "\n\t" "there is probably an instance of rpld running!\n"));
             }
         } else if(GOpt.verbose) {
-            printf("Successfully opened RPL device\n");
+            printf(_("Successfully opened RPL device\n"));
         }
         unlink(NODEPATH);
         unlink(new_dev);
@@ -420,18 +425,18 @@ static int init_device(const char *in_devs) {
 
         while((devp = HX_strsep(&devs, ":")) != NULL) {
             if((fd = open(devp, O_RDONLY)) >= 0) {
-                if(GOpt.verbose) { printf("Connected to %s\n", devp); }
+                if(GOpt.verbose) { printf(_("Connected to %s\n"), devp); }
                 break;
             }
             if(errno != ENOENT) {
-                fprintf(stderr, "static_find(): Could not open %s even"
-                 " though it exists: %s (trying next device)\n",
+                fprintf(stderr, _("static_find(): Could not open %s even"
+                 " though it exists: %s (trying next device)\n"),
                  devp, strerror(errno));
             }
             if(errno == EBUSY) {
-                fprintf(stderr, "\t" "The RPL device can only be opened"
+                fprintf(stderr, _("\t" "The RPL device can only be opened"
                  " once,\n\t" "there is probably an instance of rpld"
-                 " running!\n");
+                 " running!\n"));
             }
             ++devp;
         }
@@ -448,7 +453,12 @@ static int init_sbuffer(int fd) {
         Opt.bsize = eax;
     }
 
-    if(posix_memalign(&Buffer, sysconf(_SC_PAGESIZE), Opt.bsize) != 0) {
+#ifdef __FreeBSD__
+    if((Buffer = malloc(Opt.bsize)) == NULL)
+#else
+    if(posix_memalign(&Buffer, sysconf(_SC_PAGESIZE), Opt.bsize) != 0)
+#endif
+    {
         eax = errno;
         perror("malloc()/posix_memalign()");
         return -(errno = eax);
@@ -489,16 +499,16 @@ static const char *mknod_rpldev(void) {
             minor = -1;
         }
     } else {
-        fprintf(stderr, "Could not open either /sys/module/rpldev/Minor_nr "
-         "or /proc/misc!\n");
+        fprintf(stderr, _("Could not open either /sys/module/rpldev/Minor_nr "
+         "or /proc/misc!\n"));
         return NULL;
     }
 
     fclose(fp);
 
     if(minor < 0) {
-        printf("rpldev module does not seem to be loaded or can not find\n"
-         "minor number associated with it.\n");
+        printf(_("rpldev module does not seem to be loaded or can not find\n"
+         "minor number associated with it.\n"));
         return NULL;
     }
 
@@ -539,13 +549,13 @@ static int init_sighandler(void) {
 static void sighandler_int(int s) {
     if(Opt._running-- == 0) {
         if(GOpt.verbose) {
-            printf("Second time we received SIGINT/SIGTERM,"
-             " exiting immediately.\n");
+            printf(_("Second time we received SIGINT/SIGTERM,"
+             " exiting immediately.\n"));
         }
         exit(EXIT_FAILURE);
     }
     if(GOpt.verbose) {
-        printf("\n" "Received SIGINT/SIGTERM, shutting down.\n");
+        printf(_("\n" "Received SIGINT/SIGTERM, shutting down.\n"));
     }
     Opt._running = 0;
     return;
@@ -562,7 +572,7 @@ static void sighandler_alrm(int s) {
 }
 
 static void sighandler_pipe(int s) {
-    fprintf(stderr, "\n" "[%d] Received SIGPIPE\n", getpid());
+    fprintf(stderr, _("\n" "[%d] Received SIGPIPE\n"), getpid());
     return;
 }
 
@@ -702,7 +712,7 @@ static int read_config_bp(const char *app_path, const char *file) {
 static int pconfig_user(const char *key, unsigned char type, void *ptr,
  void *uptr) {
     if((GOpt.user_id = getuidfromname(ptr)) < 0) {
-        fprintf(stderr, "No such user: %s\n", (const char *)ptr);
+        fprintf(stderr, _("No such user: %s\n"), (const char *)ptr);
         exit(EXIT_FAILURE);
     }
     return 1;
